Don't dump loaded but unresolved classes in hprof

If a class is loaded but not yet resolved, it will cause failed
DCHECK when reading static fields.

Bug: 32008990

Test: test/run-test --host 130

Change-Id: I05f549cb2b70c75b06ed23d3405373d15ad7707b
diff --git a/runtime/hprof/hprof.cc b/runtime/hprof/hprof.cc
index 0fde380..2336759 100644
--- a/runtime/hprof/hprof.cc
+++ b/runtime/hprof/hprof.cc
@@ -1167,8 +1167,8 @@
 }
 
 void Hprof::DumpHeapClass(mirror::Class* klass) {
-  if (!klass->IsLoaded() && !klass->IsErroneous()) {
-    // Class is allocated but not yet loaded: we cannot access its fields or super class.
+  if (!klass->IsResolved() && !klass->IsErroneous()) {
+    // Class is allocated but not yet resolved: we cannot access its fields or super class.
     return;
   }
   const size_t num_static_fields = klass->NumStaticFields();